@@ -1,4 +1,4 @@
-"buffalo" <-
+buffalo <-
 c(126.4, 82.4, 78.1, 51.1, 90.9, 76.2, 104.5, 87.4, 110.5, 25, 
 69.3, 53.5, 39.8, 63.6, 46.7, 72.9, 79.6, 83.6, 80.7, 60.3, 79, 
 74.4, 49.6, 54.7, 71.8, 49.1, 103.9, 51.6, 82.4, 83.6, 77.8, 
